@@ -17,7 +17,7 @@ import os.path
 
 logger = logging.getLogger('giza.config.base')
 
-from giza.serialization import ingest_yaml_doc
+from giza.tools.serialization import ingest_yaml_doc
 
 class ConfigurationBase(object):
     _option_registry = []
@@ -50,7 +50,8 @@ class ConfigurationBase(object):
                 return self.state[key]
             else:
                 m = 'key "{0}" in configuration object does not exist'.format(key)
-                logger.debug(m)
+                if not key.startswith('__'):
+                    logger.debug(m)
                 raise AttributeError(m, e.message)
 
     @property
