@@ -14,38 +14,33 @@
 
 from giza.config.base import RecursiveConfigurationBase, ConfigurationBase
 
+def get_path_prefix(conf, branch):
+    """
+    Returns the part of a site path between the domain name and the paths
+    produced from sprint, accounting for sub-site names and branch names.
+    """
+
+    o = []
+
+    if conf.project.siteroot is True:
+        if (conf.project.branched is True and
+            conf.git.branches.manual != branch):
+            o.append(branch)
+        else:
+            o.append(conf.project.tag)
+    else:
+        o.append(conf.project.project.basepath)
+
+        if self.project.branched is True:
+            if conf.git.branches.manual == conf.git.branches.current:
+                o.append('current')
+            else:
+                o.append(branch)
+
+    return '/'.join(o)
+
 class ProjectConfig(RecursiveConfigurationBase):
-    @property
-    def name(self):
-        return self.state['name']
-
-    @name.setter
-    def name(self, value):
-        self.state['name'] = value
-
-    @property
-    def tag(self):
-        return self.state['tag']
-
-    @tag.setter
-    def tag(self, value):
-        self.state['tag'] = value
-
-    @property
-    def url(self):
-        return self.state['url']
-
-    @url.setter
-    def url(self, value):
-        self.state['url'] = value
-
-    @property
-    def title(self):
-        return self.state['title']
-
-    @title.setter
-    def title(self, value):
-        self.state['title'] = value
+    _option_registry = ['name', 'tag', 'url', 'title']
 
     @property
     def editions(self):
@@ -135,33 +130,10 @@ class ProjectConfig(RecursiveConfigurationBase):
 
     @property
     def sitepath(self):
-        o = []
-
-        if self.siteroot is True:
-            if (self.branched is True and
-                self.conf.git.branches.manual != self.conf.git.branches.current):
-                o.append(self.conf.git.branches.current)
-            else:
-                o.append(self.basepath)
-        else:
-            o.append(self.basepath)
-
-            if self.branched is True:
-                if self.conf.git.branches.manual == self.conf.git.branches.current:
-                    o.append('current')
-                else:
-                    o.append(self.conf.git.branches.current)
-
-        return '/'.join(o)
+        return get_path_prefix(self.conf, self.conf.git.branches.current)
 
 class EditionListConfig(ConfigurationBase):
-    @property
-    def name(self):
-        return self.state['name']
-
-    @name.setter
-    def name(self, value):
-        self.state['name'] = value
+    _option_registry = ['name']
 
     @property
     def branched(self):
