@@ -4,9 +4,9 @@ logger = logging.getLogger('giza.operations.generate')
 
 import argh
 
-from giza.app import BuildApp
+from giza.core.app import BuildApp
 from giza.config.helper import fetch_config
-from giza.files import rm_rf
+from giza.tools.files import rm_rf
 
 from giza.content.assets import assets_tasks, assets_clean
 from giza.content.images import image_tasks, image_clean
@@ -16,7 +16,7 @@ from giza.content.param import api_tasks, api_clean
 from giza.content.steps import steps_tasks, steps_clean
 from giza.content.table import table_tasks, table_clean
 from giza.content.toc import toc_tasks, toc_clean
-
+from giza.content.redirects import make_redirect, redirect_tasks
 from giza.content.examples.tasks import example_tasks
 
 from giza.content.primer import primer_migration_tasks
@@ -136,3 +136,16 @@ def examples(args):
     example_tasks(c, app)
 
     app.run()
+
+@argh.arg('--edition', '-e')
+@argh.arg('--print', '-p', default=False, action='store_true', dest='dry_run')
+def redirects(args):
+    c = fetch_config(args)
+
+    if args.dry_run is True:
+        print(''.join(make_redirect(c)))
+    else:
+        app = BuildApp(c)
+
+        redirect_tasks(c, app)
+        app.run()
